#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Feb 11 20:45:52 2023

@author: anton
"""

# Requirement specifications of the Hearing Loop System
from SLiCAP import *
#from SLiCAP.SLiCAPdocTools import *

Zimin = 1e4   # Minimum input impedance transmitter
Vimax = 1     # Peak input voltage transmitter
Rlmin = 2e3   # Minimum load resistance receiver
Vomax = 0.25  # Peak output voltage receiver with receive coil in center of
              # transmit loop antenna
Vonn  = 1e-4  # Maximum (no-signal) RMS output noise over frequency range
fmin  = 60    # Small-signal transfer -3dB high-pass cut-off frequency
fmax  = 15e3  # Small-signal transfer -3dB low-pass cut-off frequency
ffpl  = 60    # Minimum frequency for full-power
ffph  = 5e3   # Maximum frequency for full-power
VP    = 15    # Positive supply voltage
VN    = -15   # Negative supply voltage

# Add all this data to a table with specifications

specs = []

specs.append(
    specItem(
        "Z_i",
        description = "Transmitter input impedance",
        value    = Zimin,
        units       = "Omega",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "V_i",
        description = "Transmitter peak input voltage",
        value    = Vimax,
        units       = "V",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "R_ell",
        description = "Receiver load resistance",
        value    = Rlmin,
        units       = "Omega",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "V_o",
        description = "Receiver peak output voltage at maximum input voltage",
        value    = Vomax,
        units       = "V",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "v_on",
        description = "Zero-signal RMS output noise over -3dB frequency range",
        value    = Vonn,
        units       = "V",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "f_min",
        description = "Small-signal -3dB high-pass cut-off frequency",
        value    = fmin,
        units       = "Hz",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "f_max",
        description = "Small-signal -3dB low-pass cut-off frequency",
        value    = fmax,
        units       = "Hz",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "f_fpl",
        description = "Minimum frequency for full-power",
        value    = ffpl,
        units       = "Hz",
        specType    = "functionale",
    )
)

specs.append(
    specItem(
        "f_fpl",
        description = "Maximum frequency for full-power",
        value    = ffph,
        units       = "Hz",
        specType    = "functional",
    )
)

specs.append(
    specItem(
        "V_P",
        description = "Positive supply voltage",
        value    = VP,
        units       = "V",
        specType    = "Power supply",
    )
)

specs.append(
    specItem(
        "V_N",
        description = "Negative supply voltage",
        value    = VN,
        units       = "V",
        specType    = "Power Supply",
    )
)


# Save the specifications
specs2csv(specs, "specifications.csv")

# display the date on an html page

htmlPage("Specifications")
specs2html(specs)